==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/EducationTeacher.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "teacherNumber", 
    "externalId"})
@JsonInclude(Include.NON_NULL)
public class EducationTeacher implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("teacherNumber")
    protected String teacherNumber;

    @JsonProperty("externalId")
    protected String externalId;

    protected EducationTeacher() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.educationTeacher";
    }

    @Property(name="teacherNumber")
    @JsonIgnore
    public Optional<String> getTeacherNumber() {
        return Optional.ofNullable(teacherNumber);
    }

    public EducationTeacher withTeacherNumber(String teacherNumber) {
        EducationTeacher _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.educationTeacher");
        _x.teacherNumber = teacherNumber;
        return _x;
    }

    @Property(name="externalId")
    @JsonIgnore
    public Optional<String> getExternalId() {
        return Optional.ofNullable(externalId);
    }

    public EducationTeacher withExternalId(String externalId) {
        EducationTeacher _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.educationTeacher");
        _x.externalId = externalId;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String teacherNumber;
        private String externalId;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder teacherNumber(String teacherNumber) {
            this.teacherNumber = teacherNumber;
            this.changedFields = changedFields.add("teacherNumber");
            return this;
        }

        public Builder externalId(String externalId) {
            this.externalId = externalId;
            this.changedFields = changedFields.add("externalId");
            return this;
        }

        public EducationTeacher build() {
            EducationTeacher _x = new EducationTeacher();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.educationTeacher";
            _x.teacherNumber = teacherNumber;
            _x.externalId = externalId;
            return _x;
        }
    }

    private EducationTeacher _copy() {
        EducationTeacher _x = new EducationTeacher();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.teacherNumber = teacherNumber;
        _x.externalId = externalId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("EducationTeacher[");
        b.append("teacherNumber=");
        b.append(this.teacherNumber);
        b.append(", ");
        b.append("externalId=");
        b.append(this.externalId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/EducationTeacher.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "externalId", 
    "teacherNumber"})
@JsonInclude(Include.NON_NULL)
public class EducationTeacher implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("externalId")
    protected String externalId;

    @JsonProperty("teacherNumber")
    protected String teacherNumber;

    protected EducationTeacher() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.educationTeacher";
    }

    @Property(name="externalId")
    @JsonIgnore
    public Optional<String> getExternalId() {
        return Optional.ofNullable(externalId);
    }

    public EducationTeacher withExternalId(String externalId) {
        EducationTeacher _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.educationTeacher");
        _x.externalId = externalId;
        return _x;
    }

    @Property(name="teacherNumber")
    @JsonIgnore
    public Optional<String> getTeacherNumber() {
        return Optional.ofNullable(teacherNumber);
    }

    public EducationTeacher withTeacherNumber(String teacherNumber) {
        EducationTeacher _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.educationTeacher");
        _x.teacherNumber = teacherNumber;
        return _x;
    }

    public EducationTeacher withUnmappedField(String name, Object value) {
        EducationTeacher _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String externalId;
        private String teacherNumber;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder externalId(String externalId) {
            this.externalId = externalId;
            this.changedFields = changedFields.add("externalId");
            return this;
        }

        public Builder teacherNumber(String teacherNumber) {
            this.teacherNumber = teacherNumber;
            this.changedFields = changedFields.add("teacherNumber");
            return this;
        }

        public EducationTeacher build() {
            EducationTeacher _x = new EducationTeacher();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.educationTeacher";
            _x.externalId = externalId;
            _x.teacherNumber = teacherNumber;
            return _x;
        }
    }

    private EducationTeacher _copy() {
        EducationTeacher _x = new EducationTeacher();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.externalId = externalId;
        _x.teacherNumber = teacherNumber;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("EducationTeacher[");
        b.append("externalId=");
        b.append(this.externalId);
        b.append(", ");
        b.append("teacherNumber=");
        b.append(this.teacherNumber);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
